@@ -6,7 +6,7 @@
 ##' @param digits Number of digits to print in the table.
 ##' @param pDigits Number of digits to print for p-values (also used for standardized mean differences).
 ##' @param quote Whether to show everything in quotes. The default is FALSE. If TRUE, everything including the row and column names are quoted so that you can copy it to Excel easily.
-##' @param missing Whether to show missing data information (not implemented yet, placeholder)
+##' @param missing Whether to show missing data information.
 ##' @param explain Whether to add explanation to the variable names, i.e., (mean (sd) or median [IQR]) is added to the variable names.
 ##' @param printToggle Whether to print the output. If FLASE, no output is created, and a matrix is invisibly returned.
 ##' @param noSpaces Whether to remove spaces added for alignment. Use this option if you prefer to align numbers yourself in other software.
@@ -231,6 +231,16 @@ function(x,                       # ContTable object
     }
 
 
+    ## Add percentMissing when requested and available
+    if (missing & !is.null(attr(ContTable, "percentMissing"))) {
+
+        ## Create an empty column
+        out <- cbind(out,
+                     Missing = rep("", nrow(out))) # Column for p-values
+        ## Put the values
+        out[,"Missing"] <- ModuleFormatPercents(attr(ContTable, "percentMissing"), 1)
+    }
+
 
     ## Add mean (sd) or median [IQR]/median [range] explanation if requested
     if (explain) {
