@@ -7,12 +7,13 @@
 ##' @param contDigits Number of digits to print for continuous variables. Default 2.
 ##' @param pDigits Number of digits to print for p-values (also used for standardized mean differences). Default 3.
 ##' @param quote Whether to show everything in quotes. The default is FALSE. If TRUE, everything including the row and column names are quoted so that you can copy it to Excel easily.
-##' @param missing Whether to show missing data information (not implemented yet, placeholder)
+##' @param missing Whether to show missing data information.
 ##' @param explain Whether to add explanation to the variable names, i.e., (\%) is added to the variable names when percentage is shown.
 ##' @param printToggle Whether to print the output. If FLASE, no output is created, and a matrix is invisibly returned.
 ##' @param test Whether to show p-values. TRUE by default. If FALSE, only the numerical summaries are shown.
 ##' @param smd Whether to show standardized mean differences. FALSE by default. If there are more than one contrasts, the average of all possible standardized mean differences is shown. For individual contrasts, use \code{summary}.
 ##' @param noSpaces Whether to remove spaces added for alignment. Use this option if you prefer to align numbers yourself in other software.
+##' @param padColnames Whether to pad column names with spaces to center justify. The default is FALSE. It is not conducted if noSpaces = TRUE.
 ##' @param format The default is "fp" frequency (percentage). You can also choose from "f" frequency only, "p" percentage only, and "pf" percentage (frequency).
 ##' @param showAllLevels Whether to show all levels. FALSE by default, i.e., for 2-level categorical variables, only the higher level is shown to avoid redundant information.
 ##' @param cramVars A character vector to specify the two-level categorical variables, for which both levels should be shown in one row.
@@ -39,8 +40,9 @@ function(x,                   # TableOne object
          explain       = TRUE,  # Whether to show explanation in variable names
          printToggle   = TRUE,  # Whether to print the result visibly
          test          = TRUE,  # Whether to add p-values
-         smd           = FALSE,  # Whether to add standardized mean differences
+         smd           = FALSE, # Whether to add standardized mean differences
          noSpaces      = FALSE, # Whether to remove spaces for alignments
+         padColnames   = FALSE, # Whether to pad column names for alignments
 
          ## Categorical options
          format        = c("fp","f","p","pf")[1], # Format f_requency and/or p_ercent
@@ -57,7 +59,7 @@ function(x,                   # TableOne object
     ## Extract Cont/CatTable elements of x and dispatch print() appropriately
     FmtTables <- ModuleFormatTables(x,
                                     catDigits = catDigits, contDigits = contDigits,
-                                    test = test, smd = smd,
+                                    test = test, smd = smd, missing = missing,
                                     explain = explain, pDigits = pDigits,
 
                                     ## print.CatTable arguments passed
@@ -131,6 +133,16 @@ function(x,                   # TableOne object
         names(dimnames(out)) <- c("", "")
     }
 
+    ## Right-justify Missing column if showing and not removing spaces.
+    if (missing & !noSpaces) {
+        out[,"Missing"] <- format(out[,"Missing"], justify = "right")
+    }
+
+    ## Center-justify column names if asked and not removing spaces.
+    if (padColnames & !noSpaces) {
+        out <- ModuleMidJustifyColnames(mat = out)
+    }
+
     ## Remove spaces if asked.
     out <- ModuleRemoveSpaces(mat = out, noSpaces = noSpaces)
 
