@@ -429,13 +429,14 @@ test_that("decent results are returned for anomalous/difficult data", {
     expect_equal(svyStdDiffMulti("race2", group = "race", design = nhanesSvy), rep(NaN, 6))
 
 
-    ## Only one value
-    ## NaN due to division by zero variance
+    ## Identical constant comparison
+    ## T-C vector is a zero vector, but divisor is also zero
+    ## NaN due to division by zero variance -> Redefined as zero
     by(nhanes$onlyOne, nhanes$RIAGENDR, summary)
-    expect_equal(StdDiff(nhanes$onlyOne, group = nhanes$RIAGENDR), NaN)
+    expect_equal(StdDiff(nhanes$onlyOne, group = nhanes$RIAGENDR), 0)
     ## 0 because [0]^-  = 0, and [1]^T [0]^-1 [1] = 0; defined NaN in (svy)StdDiffMulti
     table(nhanes$onlyOne, nhanes$RIAGENDR)
-    expect_equal(StdDiffMulti(nhanes$onlyOne, group = nhanes$RIAGENDR), NaN)
+    expect_equal(StdDiffMulti(nhanes$onlyOne, group = nhanes$RIAGENDR), 0)
     ## When weighted problematic
     means1 <- svyby(~ onlyOne, by = ~ RIAGENDR, nhanesSvy, FUN = svymean)[,2]
     vars1  <- svyby(~ onlyOne, by = ~ RIAGENDR, nhanesSvy, FUN = svyvar)[,2]
@@ -451,15 +452,15 @@ test_that("decent results are returned for anomalous/difficult data", {
     ## No error even with a single level variable (constant) as redundant
     ## level drop from table occurs only when 2+ levels are present.
     ## If any group has more than 2 levels, then strata-by-level table
-    ## is correctly created, which is not the case here. Redefined NaN.
-    expect_equal(svyStdDiffMulti("onlyOne", "RIAGENDR", nhanesSvy), NaN)
+    ## is correctly created, which is not the case here. Redefined as 0.
+    expect_equal(svyStdDiffMulti("onlyOne", "RIAGENDR", nhanesSvy), 0)
 
     ## Four groups (six contrasts)
-    ## NaN due to division by zero variance
+    ## NaN due to division by zero variance -> Redefined as 0
     by(nhanes$onlyOne, nhanes$race, summary)
-    expect_equal(StdDiff(nhanes$onlyOne, group = nhanes$race), rep(NaN, 6))
+    expect_equal(StdDiff(nhanes$onlyOne, group = nhanes$race), rep(0, 6))
     ## 0 because [0]^-  = 0, and [1]^T [0]^-1 [1] = 0; defined NaN in (svy)StdDiffMulti
-    expect_equal(StdDiffMulti(nhanes$onlyOne, group = nhanes$race), rep(NaN, 6))
+    expect_equal(StdDiffMulti(nhanes$onlyOne, group = nhanes$race), rep(0, 6))
     ## When weighted problematic; not in this case??
     means2 <- svyby(~ onlyOne, by = ~ race, nhanesSvy, FUN = svymean)[,2]
     vars2  <- svyby(~ onlyOne, by = ~ race, nhanesSvy, FUN = svyvar)[,2]
@@ -469,20 +470,10 @@ test_that("decent results are returned for anomalous/difficult data", {
                     (means2[2] - means2[3]) / sqrt((vars2[2] + vars2[3]) / 2),
                     (means2[2] - means2[4]) / sqrt((vars2[2] + vars2[4]) / 2),
                     (means2[3] - means2[4]) / sqrt((vars2[3] + vars2[4]) / 2))
-    ## on sparc-sun-solaris sign was opposite; abs() solves this issue
-    ## as svyStdDiff() uses abs() internally
-    expect_equal(svyStdDiff("onlyOne", "race", nhanesSvy), abs(meanDiffs2))
-    ## This one is rep(NaN,6) for most platforms except for sparc-sun-solaris
-    ## where ./configure --disable-long-double is used.
-    ## capabilities()["long.double"] was added in R 3.1.3.
-    ## As of 2015-08-11, only r-oldrel-windows-ix86+x86_64 is R 3.1.3.
-    ## https://cran.r-project.org/web/checks/check_results_tableone.html
-    if (capabilities()["long.double"]) {
-        ## Cannot run on sparc-sun-solaris due to lack of extended precision arithmetic
-        expect_equal(svyStdDiff("onlyOne", "race", nhanesSvy), rep(NaN, 6))
-    }
+    ## Redefined as 0 as T-C is a zero vector
+    expect_equal(svyStdDiff("onlyOne", "race", nhanesSvy), rep(0,6))
     ## 0 because [0]^-  = 0, and [1]^T [0]^-1 [1] = 0; defined NaN in (svy)StdDiffMulti
-    expect_equal(svyStdDiffMulti("onlyOne", "race", nhanesSvy), rep(NaN, 6))
+    expect_equal(svyStdDiffMulti("onlyOne", "race", nhanesSvy), rep(0, 6))
 
 
     ## onlyNa
@@ -490,8 +481,8 @@ test_that("decent results are returned for anomalous/difficult data", {
     expect_warning(expect_equal(StdDiff(nhanes$onlyNa, group = nhanes$RIAGENDR),
                                 as.numeric(NA)),
                    "Variable has only NA's in at least one stratum. na.rm turned off.")
-    ## 0 only one level
-    expect_warning(expect_equal(StdDiffMulti(nhanes$onlyNa, group = nhanes$RIAGENDR), NaN),
+    ## defined 0 as NA is a level
+    expect_warning(expect_equal(StdDiffMulti(nhanes$onlyNa, group = nhanes$RIAGENDR), 0),
                    "Variable has only NA's in all strata. Regarding NA as a level")
     ## When weighted problematic
     means1 <- svyby(~ onlyNa, by = ~ RIAGENDR, nhanesSvy, FUN = svymean)[,2]
@@ -503,7 +494,7 @@ test_that("decent results are returned for anomalous/difficult data", {
                                 as.numeric(NA)),
                    "onlyNa has only NA's in at least one stratum. na.rm turned off.")
     ## 0 because [0]^-  = 0, and [1]^T [0]^-1 [1] = 0; defined NaN in (svy)StdDiffMulti
-    expect_warning(expect_equal(svyStdDiffMulti("onlyNa", "RIAGENDR", nhanesSvy), NaN),
+    expect_warning(expect_equal(svyStdDiffMulti("onlyNa", "RIAGENDR", nhanesSvy), 0),
                    "onlyNa has only NA's in all strata. Regarding NA as a level.")
 
     ## Four groups (six contrasts)
@@ -511,7 +502,7 @@ test_that("decent results are returned for anomalous/difficult data", {
     expect_warning(expect_equal(StdDiff(nhanes$onlyNa, group = nhanes$race), rep(NaN, 6)),
                    "Variable has only NA's in at least one stratum. na.rm turned off.")
     ## 0 because [0]^-  = 0, and [1]^T [0]^-1 [1] = 0; defined NaN in (svy)StdDiffMulti
-    expect_warning(expect_equal(StdDiffMulti(nhanes$onlyNa, group = nhanes$race), rep(NaN, 6)),
+    expect_warning(expect_equal(StdDiffMulti(nhanes$onlyNa, group = nhanes$race), rep(0, 6)),
                    "Variable has only NA's in all strata. Regarding NA as a level.")
     ## When weighted problematic; not in this case??
     means2 <- svyby(~ onlyNa, by = ~ race, nhanesSvy, FUN = svymean)[,2]
@@ -526,8 +517,8 @@ test_that("decent results are returned for anomalous/difficult data", {
                    "onlyNa has only NA's in at least one stratum. na.rm turned off.")
     expect_warning(expect_equal(svyStdDiff("onlyNa", "race", nhanesSvy), rep(NaN, 6)),
                    "onlyNa has only NA's in at least one stratum. na.rm turned off.")
-    ## 0 because [0]^-  = 0, and [1]^T [0]^-1 [1] = 0; defined NaN in (svy)StdDiffMulti
-    expect_warning(expect_equal(svyStdDiffMulti("onlyNa", "race", nhanesSvy), rep(NaN, 6)),
+    ## 0 because [0]^-  = 0, and [1]^T [0]^-1 [1] = 0; defined 0 as NA is a level
+    expect_warning(expect_equal(svyStdDiffMulti("onlyNa", "race", nhanesSvy), rep(0, 6)),
                    "onlyNa has only NA's in all strata. Regarding NA as a level.")
 
 })
@@ -1084,7 +1075,8 @@ test_that("SMDs are correctly shown in print()", {
                  StdDiffMulti(nhanes$agecat, nhanes$strataVar))
 
     out1 <- print(tab1, smd = TRUE)
-    expect_equal(as.vector(out1[,"SMD"][2:3]),
+    ## With default test = TRUE, missing = FALSE, last column should be SMD.
+    expect_equal(as.vector(out1[,ncol(out1)][2:3]),
                  c(sprintf(" %.3f", attr(tab1$ContTable, "smd")[1,1]),
                    sprintf(" %.3f", attr(tab1$CatTable, "smd")[1,1])))
 
